summaryrefslogtreecommitdiffstats
path: root/ash/launcher/launcher.h
diff options
context:
space:
mode:
authorsky@chromium.org <sky@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-10 15:43:53 +0000
committersky@chromium.org <sky@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-05-10 15:43:53 +0000
commit5544450654bfa0c36809e104014dd96215d05b4d (patch)
treecdf089e5aff5c4f5329648ddf06751fd3adc6f74 /ash/launcher/launcher.h
parentb0055b9c2fb9713631930dfa95d1112b0c7ec590 (diff)
downloadchromium_src-5544450654bfa0c36809e104014dd96215d05b4d.zip
chromium_src-5544450654bfa0c36809e104014dd96215d05b4d.tar.gz
chromium_src-5544450654bfa0c36809e104014dd96215d05b4d.tar.bz2
Adds the option of aligning the launcher to the left or right. There
is a ton of rough edges after this patch, but I don't want this patch to get any bigger. BUG=121962 TEST=covered by tests. R=ben@chromium.org Review URL: https://chromiumcodereview.appspot.com/10388036 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@136312 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/launcher/launcher.h')
-rw-r--r--ash/launcher/launcher.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/ash/launcher/launcher.h b/ash/launcher/launcher.h
index 792d578..9af34bb 100644
--- a/ash/launcher/launcher.h
+++ b/ash/launcher/launcher.h
@@ -9,8 +9,10 @@
#include "ash/ash_export.h"
#include "ash/launcher/background_animator.h"
#include "ash/launcher/launcher_types.h"
+#include "ash/wm/shelf_auto_hide_behavior.h"
#include "base/basictypes.h"
#include "base/memory/scoped_ptr.h"
+#include "ui/gfx/size.h"
namespace aura {
class Window;
@@ -45,15 +47,18 @@ class ASH_EXPORT Launcher : public internal::BackgroundAnimatorDelegate {
void SetFocusCycler(internal::FocusCycler* focus_cycler);
internal::FocusCycler* GetFocusCycler();
+ void SetAlignment(ShelfAlignment alignment);
+ ShelfAlignment alignment() const { return alignment_; }
+
// Sets whether the launcher paints a background. Default is false, but is set
// to true if a window overlaps the shelf.
void SetPaintsBackground(
bool value,
internal::BackgroundAnimator::ChangeType change_type);
- // Sets the width of the status area.
- void SetStatusWidth(int width);
- int GetStatusWidth();
+ // Sets the size of the status area.
+ void SetStatusSize(const gfx::Size& size);
+ const gfx::Size& status_size() const { return status_size_; }
// Returns the screen bounds of the item for the specified window. If there is
// no item for the specified window an empty rect is returned.
@@ -104,8 +109,13 @@ class ASH_EXPORT Launcher : public internal::BackgroundAnimatorDelegate {
// LauncherView used to display icons.
internal::LauncherView* launcher_view_;
+ ShelfAlignment alignment_;
+
scoped_ptr<LauncherDelegate> delegate_;
+ // Size reserved for the status area.
+ gfx::Size status_size_;
+
// Used to animate the background.
internal::BackgroundAnimator background_animator_;